import abc


class Entity(abc.ABC):
    def serialize(self) -> dict:
        pass


class UseCase(abc.ABC):
    """領域的用例"""
    pass


class Service(abc.ABC):
    """領域的服務"""
    pass


class Repository(abc.ABC):
    """領域的儲存庫"""
    pass


class Helper(abc.ABC):
    """工具包"""
    pass



class BaseError(Exception):

    def __init__(self, reason):
        self.reason = reason

    def __str__(self):
        return f'<{self.__class__.__name__}({self.reason})>'


class NotFoundError(BaseError):
    pass


class DataError(BaseError):
    pass


class ValidationError(BaseError):
    pass



# mypy: ignore_errors
import os

import setuptools

base_dir = os.path.abspath(os.path.dirname(__file__))

REQUIREMENTS = []
with open(os.path.join(base_dir, 'requirements.txt'), encoding='utf-8') as fp:
    for line in fp.readlines():
        line = line.strip()
        if line and not line.startswith('#'):
            REQUIREMENTS.append(line)

with open(os.path.join(base_dir, 'README.md'), encoding='utf-8') as fp:
    long_description = fp.read()

setuptools.setup(
    name="paji-sdk",
    version='0.2.1',
    author='兩大類',
    author_email='marco79423@gmail.com',
    url='https://github.com/marco79423/paji-sdk',
    python_requires='>=3.6',
    description='Python 開發工具包',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=setuptools.find_packages(),
    install_requires=REQUIREMENTS,
    include_package_data=True,
    classifiers=[
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)



from typing import Any

class BaseError(Exception):
    reason: Any
    def __init__(self, reason) -> None: ...

class NotFoundError(BaseError): ...
class DataError(BaseError): ...
class ValidationError(BaseError): ...
